@@ -12,7 +12,7 @@
 #' @return A \link{MulticoreFuture}
 #' If \code{workers == 1}, then all processing using done in the
 #' current/main R session and we therefore fall back to using
-#' a eager future.  This is also the case whenever multicore
+#' an eager future.  This is also the case whenever multicore
 #' processing is not supported, e.g. on Windows.
 #'
 #' @example incl/multicore.R
@@ -62,12 +62,12 @@ multicore <- function(expr, envir=parent.frame(), substitute=TRUE, globals=TRUE,
   workers <- as.integer(workers)
   stopifnot(is.finite(workers), workers >= 1L)
 
-  ## Fall back to eager futures if only a single additional R process
+  ## Fall back to eager uniprocess futures if only a single additional R process
   ## can be spawned off, i.e. then use the current main R process.
-  ## Eager futures best reflect how multicore futures handle globals.
+  ## Uniprocess futures best reflect how multicore futures handle globals.
   if (workers == 1L || !supportsMulticore()) {
     ## covr: skip=1
-    return(eager(expr, envir=envir, substitute=FALSE, globals=globals, local=TRUE, label=label))
+    return(uniprocess(expr, envir=envir, substitute=FALSE, globals=globals, local=TRUE, label=label, lazy=FALSE))
   }
 
   oopts <- options(mc.cores=workers)
