@@ -61,7 +61,7 @@ for (strategy in supportedStrategies()) {
   print(f)
   rm(list=names(globals))
   y <- tryCatch(value(f), error = identity)
-  if (!inherits(f, c("EagerFuture", "MulticoreFuture"))) {
+  if (!inherits(f, c("UniprocessFuture", "MulticoreFuture"))) {
     stopifnot(inherits(y, "simpleError"))
   }
 
